darkhistory.low_energy.lowE_electrons — DarkHistory documentation

# darkhistory.low_energy.lowE_electrons

Functions

`compute_fs`(MEDEA_interp, spec_elec, xe, …) | Given an electron energy spectrum, calculate how much of that energy splits into continuum photons, lyman_alpha transitions, H ionization, He ionization, and heating of the IGM.
`make_interpolator`([interp_type]) | Creates cubic splines that interpolate the Medea Data.

#### Previous topic

darkhistory.low_energy.lowE_deposition.compute_fs

#### Next topic

darkhistory.low_energy.lowE_electrons.compute_fs

### This Page

Show Source